# Hyperworks-Tools!

## Purpose

This repository will be the place where I want to develop Hyperworks tools for automating different stuff. 
The first thing, which I did here was automatic extraction of objective values from multiple Simulations.
Preprocessing stuff is planned - like generating template models based on inputs and more. I will update the general info here and the documentation.
I also want to implement software development standards here, as for automatic testing and deploying but there is still much to learn for me so don't expect it to be perfect right from the start. 

## Documentation

Find the documentation [here](https://manuel1618.github.io/hyperworks-tools/) (GitHub Pages/mkdocs)


## License

MIT

